<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\MAN\Services;

class ParaVendasImposto extends CrudWithParameterBag {
    
    protected $dataSourceNames = array (
        'filterImposto'                     => 'paraVendasImposto',
        'filterImpostoProduto'              => 'paraVendasImpostoProduto',
        'filterImpostoProdutos'             => 'paraVendasImpostoProdutos',
        'selectImpostoProduto'              => 'select_paraVendasImpostoProduto',
        'filterCliente'                     => 'paraVendasCliente',
        'filterBanco'                       => 'paraVendasBanco',
        'filterTabelaPreco'                 => 'paraVendasClienteTabelaPreco',
        'filterTabelas'                     => 'paraVendasClienteTabelas',
        'selectTabPrec'                     => 'paraVendasClienteTabPrecSelect',
        'selectCst'                         => 'vnd10003_paramGerais_CST',
        'selectCstSat'                      => 'vnd10003_paramGerais_CST_PIS_COFINS_SAT',
        'selectCstcsosn'                    => 'vnd10003_paramGerais_CSTCSOSN',
        'selectCstcsosnImpoSubsTrib'        => 'vnd10003_paramGerais_CSTCSOSNImpoSubsTrib',
        'selectCodcfop'                     => 'vnd10003_paramGerais_CODCFOP',
        'selectCodcfop_CSTCSOSN'            => 'vnd10003_paramGerais_CODCFOP_CSTCSOSN',
        'selectAliCONFINS'                  => 'vnd10003_paramGerais_aliquotaCONFINS',
        'selectAliPIS'                      => 'vnd10003_paramGerais_aliquotaPIS',
        'selectCEST'                        => 'vnd10003_paramGerais_codCEST',
        'selectImpostoProduto_Exists'       => 'paraVendasImpostoProduto_Exists',
        'selectImpostoProdutos_Exists'      => 'paraVendasImpostoProdutos_Exists',
        'ProdutosRepoImpostos'              => 'ProdutosRepoImpostos',
        'selectImpostoProdutos_Exists_Lista'=> 'paraVendasImpostoProdutos_ExistsLista',
        'filterImpProdSegFam'               => 'filterImpProdSegFam',
        'filterImpProdFamilia'              => 'filterImpProdFamilia',
        'filterImpProdSegmento'             => 'filterImpProdSegmento',
        'filterImpProdTodos'                => 'paraVendasImpostoProduto',
        'filterModProd'                     => 'filterModProd'
    );
    
    protected  $ParaVendasImposto;
    
    
    protected  $parameterBagColumnsCFOP                   = array('NRORG'),
               $parameterBagColumnsCSTCSOSN               = array('NRORG'),
               $parameterBagColumnsImposto                = array('NRORG'),
               $parameterBagColumnsCST                    = array('NRORG'),
               $parameterBagColumnsCEST                   = array('NRORG'),
               $parameterBagColumnsClienteTabelaPreco     = array('NRORG'),
               $parameterBagColumnsBanco                  = array('NRORG'),
               $parameterBagColumnsCliente                = array('NRORG', 'CDFILIAL'),
               $parameterBagColumnsClienteTabelas         = array('NRORG', 'CDCLIENTE'),
               $parameterBagColumnsCONFINS_PIS            = array('NRORG', "CDSITUTRIBNFE"),
               $parameterBagColumnsSelectTabPrec          = array('NRORG', 'CDFILIAL', 'CDTABPREC'),
               $parameterBagColumnsImpostoProduto_Exists  = array('NRORG', 'CDFILIAL', 'CDPRODUTO'),
               $parameterBagColumnsImpostoProduto         = array('NRORG', 'CDFILIAL', 'TCDARVPROD', 'CDARVPROD','CDSEGMER','CDNVPRODUTO'), 
               $parameterBagColumnsSelectImpostoProduto   = array('NRORG', 'CDFILIAL', 'CDARVPROD' , 'LIMIT_CDARVPROD','TCDARVPROD'),
               $parameterBagColumnsImpostoProdutos        = array('NRORG', 'CDFILIAL', 'CDPRODINICIAL', 'CDPRODFINAL'), 
               $parameterBagColumnsImpostoProdutos_Exists = array('NRORG', 'CDFILIAL', 'CDPRODINICIAL', 'CDPRODFINAL'),
               $parameterBagColumnsImpostoProdutosList    = array('NRORG', 'CDFILIAL', 'CDPRODUTO');
    
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, $connection, Services\ParaVendasImposto $ParaVendasImposto) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->ParaVendasImposto = $ParaVendasImposto;
        $this->connection = $connection;
    }
    
    public function findImposto(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['filterImposto'];
        $this->parameterBagColumns = $this->parameterBagColumnsImposto;
        parent::find($request, $response);
    }
    
    public function saveImposto(DTO\Request\DataSet $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['filterImposto'];
        try {
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceName);
            $persistedRows = $this->dataSourceManager->persist($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceName, $persistedRows));
            $nrPersistedRows = count($persistedRows);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    } 
    
    public function findImpostoProduto(DTO\Request\Filter $request, DTO\Response $response) {
        $this->parameterBagColumns = $this->parameterBagColumnsImpostoProduto;
        $conditions = $request->getFilterCriteria()->getConditions();
        foreach ($conditions as $value) {
            $params[$value['columnName']] = $value['value'];
        }
        foreach ($conditions as &$Collum) {
            if($Collum['columnName'] == 'CDARVPROD' && !isset($arv)) {
                $Collum['value'] =  str_replace("%", "",  $Collum['value']);
            } 
            if($Collum['columnName'] == 'TCDARVPROD' && !isset($params['CDARVPROD'])) {
                $Collum['value'] = 'T';
                $arv = array('columnName' => 'CDARVPROD',
                            'value' => NULL,
                            'operator' => '=');
                array_push($conditions, $arv);
            }
        }
        
        $adqParams = $this->ParaVendasImposto->getParamentrosFind($conditions);
        foreach ($conditions as &$Collum) {
            if($Collum['columnName'] == 'CDSEGMER'){
                $Collum['value'] = $adqParams['CDSEGMER'];
            }
        }
        $A=$this->dataSourceName = $this->dataSourceNames[$adqParams['DATA_SOURCE']];
        $newRequest = new DTO\Request\Filter (
            new FilterCriteria(
                $this->dataSourceName,
                $conditions,
                $request->getFilterCriteria()->getPage()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        parent::find($newRequest, $response);
    }
    
    
    private function createFilterCriteria($params) {
        $filterCriteria = new FilterCriteria ($this->dataSourceName);
        
        foreach($params as $name => $value) {
            $filterCriteria->addCondition($name, '=', $value);
        }
        
        return $filterCriteria;
    }
    
    public function saveImpostoProduto(DTO\Request\DataSet $request, DTO\Response $response) {
        $row = $request->getDataSet()->getRows()[0];
        if($row['VRPEALIMPFIS']==null){
            $row['VRPEALIMPFIS']=('00.0');
        }
        $params = array (
            'CDPRODUTO' => $row['CDPRODUTO'],
            'CDFILIAL'  => $row['CDFILIAL'],
            'NRORG'     => $row['NRORG']
        );
        
        $filterCriteria = $this->createFilterCriteria($params);
        
        $newRequest = new DTO\Request\Filter (
            $filterCriteria,
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        ); 
        
        $newResponse = new DTO\Response();
        
        $result = $this->ParaVendasImposto->verificarCaixaNFC($row);
        if($result == true){
            $obrigatorio = $this->ParaVendasImposto->validaObrigatorio($row);
            if($obrigatorio["message"]!=""){
            $response ->addMessage(new Message($obrigatorio["message"], Message::TYPE_ERROR));
            return $response;
            }
        }
        
        $this->dataSourceName = $this->dataSourceNames['selectImpostoProduto_Exists'];
        $this->parameterBagColumns = $this->parameterBagColumnsImpostoProduto_Exists;
        parent::find($newRequest, $newResponse);
        
        $produto = $newResponse->getDataSets()[0]->getRows();
        if(!empty($produto)) {
            $this->ParaVendasImposto->deleteProdutoImposto($produto[0]);
        }
        // Insert or Update based on his searches results.
        $this->dataSourceName = $this->dataSourceNames['filterImpostoProduto'];
        $row['__is_new'] = (empty($produto));
        
        $row = $this->fixSaveImpostoProdutosParameters($row);
        $this->ParaVendasImposto->saveProdutoImposto($row);
        $response->addDataSet(new DataSet($this->dataSourceName, array($row)));
    }

    public function saveImpostoProdutos (DTO\Request\DataSet $request, DTO\Response $response) {
        $row = $request->getDataSet()->getRows()[0];
        
        $params = array (
            'CDFILIAL'  => $row['CDFILIAL'],
            'NRORG'     => $row['NRORG']
        );
        if(isset($row['CDPRODUTOINI'])){
            $this->dataSourceName = $this->dataSourceNames['selectImpostoProdutos_Exists'];
            $this->parameterBagColumns = $this->parameterBagColumnsImpostoProdutos_Exists;
            $filterCriteria = $this->createFilterCriteria($params);
            $filterCriteria->addCondition( 'CDPRODINICIAL', FilterCriteria::GT , $row['CDARVPRODINI']);
            $filterCriteria->addCondition( 'CDPRODFINAL', FilterCriteria::LTE, $row['CDARVPRODFIN']  );
        
            $newRequest = new DTO\Request\Filter (
                $filterCriteria,
                $request->getMethod(),
                $request->getRoutePath(),
                $request->getUserId()
            );
            
            $newResponse = new DTO\Response();
    
            parent::find($newRequest, $newResponse);
            
            $productsAlreadyRegistered = $newResponse->getDataSets()[0]->getRows(); 
        
            $this->ParaVendasImposto->deleteProdutosImposto($productsAlreadyRegistered);
            
            
            $this->dataSourceName = $this->dataSourceNames['filterImpostoProdutos'];
            $this->parameterBagColumns = $this->parameterBagColumnsImpostoProdutos;
            
            $newResponse2 = new DTO\Response();
            parent::find($newRequest, $newResponse2);
            $productsToRegister = $newResponse2->getDataSets()[0]->getRows(); 
            
            $row = $this->fixSaveImpostoProdutosParameters($row);
            $this->ParaVendasImposto->saveProdutosImposto($productsToRegister, $row);
            
            $response->addDataSet(new DataSet($this->dataSourceName, $productsToRegister));
            
        }else{
            $this->dataSourceName = $this->dataSourceNames['selectImpostoProdutos_Exists_Lista'];
            $this->parameterBagColumns = $this->parameterBagColumnsImpostoProdutosList;
            $filterCriteria = $this->createFilterCriteria($params);
            $produtos = $this->buildParamValue($row['CDPRODUTO_SM']);
            $filterCriteria->addCondition( 'CDPRODUTO', FilterCriteria::GT , $produtos);
            $newRequest = new DTO\Request\Filter (
                $filterCriteria,
                $request->getMethod(),
                $request->getRoutePath(),
                $request->getUserId()
            );
            $newResponse = new DTO\Response();

            parent::find($newRequest, $newResponse);
            
            $productsAlreadyRegistered = $newResponse->getDataSets()[0]->getRows();
            $this->ParaVendasImposto->deleteProdutosImposto($productsAlreadyRegistered);
            
            $productsToRegister = $row['CDPRODUTO_SM'];
            $row = $this->fixSaveImpostoProdutosParameters($row);
            $this->ParaVendasImposto->saveProdutosImpostoLista($productsToRegister, $row);
            
            $response->addDataSet(new DataSet('paraVendasImpostoProdutos', $productsToRegister));
        }
        

    }
    
    private function fixSaveImpostoProdutosParameters($row) {
        $row['VRPEALIMPFIS']    = array_key_exists('VRPEALIMPFIS', $row)    ? $row['VRPEALIMPFIS']      : null; 
        $row['VRPERCREDUCAO']   = array_key_exists('VRPERCREDUCAO', $row)   ? $row['VRPERCREDUCAO']     : null; 
        $row['IDMODALBASECALC'] = array_key_exists('IDMODALBASECALC', $row) ? $row['IDMODALBASECALC']   : null; 
        $row['IDINCIDEPISCOF']  = array_key_exists('IDINCIDEPISCOF', $row)  ? $row['IDINCIDEPISCOF']    : null; 
        $row['VRALIQIBPT']      = array_key_exists('VRALIQIBPT', $row)      ? $row['VRALIQIBPT']        : null; 
        $row['VRALIQIBPTES']    = array_key_exists('VRALIQIBPTES', $row)    ? $row['VRALIQIBPTES']      : null; 
        $row['CDCFOPPFIS']      = array_key_exists('CDCFOPPFIS', $row)      ? $row['CDCFOPPFIS']        : null; 
        $row['CDCSTICMS']       = array_key_exists('CDCSTICMS', $row)       ? $row['CDCSTICMS']         : null; 
        $row['CDCSTPISCOF']     = array_key_exists('CDCSTPISCOF', $row)     ? $row['CDCSTPISCOF']       : null; 
        $row['VRALIQPIS']       = array_key_exists('VRALIQPIS', $row)       ? $row['VRALIQPIS']         : null; 
        $row['VRALIQCOFINS']    = array_key_exists('VRALIQCOFINS', $row)    ? $row['VRALIQCOFINS']      : null;
        $row['CDCEST']          = array_key_exists('CDCEST', $row)          ? $row['CDCEST']            : null;
        $row['VRALIQFCP']       = array_key_exists('VRALIQFCP', $row)       ? $row['VRALIQFCP']         : null;
        $row['VRPEALIMPFISEF']  = array_key_exists('VRPEALIMPFISEF', $row)  ? $row['VRPEALIMPFISEF']    : null;
        $row['VRPERCREDUCAOEF'] = array_key_exists('VRPERCREDUCAOEF', $row) ? $row['VRPERCREDUCAOEF']   : null;
        $row['CDCBENEF']        = array_key_exists('CDCBENEF', $row)        ? $row['CDCBENEF']          : null;
        $row['VRALIQICMSDES']   = array_key_exists('VRALIQICMSDES', $row)   ? $row['VRALIQICMSDES']     : null;
        
        $row['__is_new'] = true;
        
        return $row;
    } 
    
    
    public function findBanco(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['filterBanco'];
        $this->parameterBagColumns = $this->parameterBagColumnsBanco;
        parent::find($request, $response);
    }
    
    public function saveBanco(DTO\Request\DataSet $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['filterBanco'];
        $this->save($request, $response);
    }
    
    public function findCliente(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['filterCliente'];
        $this->parameterBagColumns = $this->parameterBagColumnsCliente;
        
        parent::find($request, $response);
    }
    
    // Trocar dataSourceName no request e usar o parent
    public function saveCliente(DTO\Request\DataSet $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['filterCliente'];
        $this->save($request,$response);
    } 
    
    public function findTabelaPreco(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['filterTabelaPreco'];
        $this->parameterBagColumns = $this->parameterBagColumnsClienteTabelaPreco;
        parent::find($request, $response);
    }
    
    public function findTabelas(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['filterTabelas'];
        $this->parameterBagColumns = $this->parameterBagColumnsClienteTabelas;
        parent::find($request, $response);
    }
    
    // Essa Query poderia estar no query.php
    // Isso poderia estar em um service
    public function saveTabelas(DTO\Request\DataSet $request, DTO\Response $response) {
        $data = $request->getDataSet()->getRows();
        $queryLoja = "UPDATE CLIENFILIAL 
                    SET
                      CDTABEPREC = :CDTABEPREC,
                      CDCFILTABPRE = :CDCFILTABPRE
                    WHERE
                        (NRORG = :NRORG) 
                        AND 
                        (CDCLIENTE = :CDCLIENTE)
                        AND
                        (CDFILIAL = :CDFILIAL)";
                        
        $stmt = $this->connection->prepare($queryLoja); 
		$stmt->execute(array(
		    
		    "CDTABEPREC" => $data[0]['CDTABEPREC'],
		    "NRORG" => $data[0]['NRORG'],
		    "CDCLIENTE" => $data[0]['CDCLIENTE'],
		    "CDCFILTABPRE" => isset($data[0]['CDFILTABPREC']) ? $data[0]['CDFILTABPREC'] : "",
		    "CDFILIAL" => $data[0]['CDFILIAL']
            
		));
    }
    
    public function selectTabelaPreco(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['selectTabPrec'];
        $this->parameterBagColumns = $this->parameterBagColumnsSelectTabPrec;
        parent::find($request, $response);
    }
    
    public function selectCFOP(DTO\Request\Filter $request, DTO\Response $response) {
      $conditions = $request->getFilterCriteria()->getConditions();
        foreach ($conditions as $value) {
                $params[$value['columnName']] = $value['value'];
            }
        $CSTCSON = $params['CDCSTICMS'];
        unset($conditions[1]);
            if($CSTCSON == 60 || $CSTCSON == 500){
                $this->dataSourceName = $this->dataSourceNames['selectCodcfop_CSTCSOSN'];
                $this->parameterBagColumns = $this->parameterBagColumnsCFOP;
                
                $newRequest = new DTO\Request\Filter (
                    new FilterCriteria(
                        $this->dataSourceName,
                        $conditions,
                        $request->getFilterCriteria()->getPage()
                    ),
                    $request->getMethod(),
                    $request->getRoutePath(),
                    $request->getUserId()
                );
                parent::find($newRequest, $response);
            }
            else{
                
            $this->dataSourceName = $this->dataSourceNames['selectCodcfop'];
            $this->parameterBagColumns = $this->parameterBagColumnsCFOP;
            
             $newRequest = new DTO\Request\Filter (
                    new FilterCriteria(
                        $this->dataSourceName,
                        $conditions,
                        $request->getFilterCriteria()->getPage()
                    ),
                    $request->getMethod(),
                    $request->getRoutePath(),
                    $request->getUserId()
                );
            parent::find($newRequest, $response);
            }
    }
    
    public function selectCSTCSOSN(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['selectCstcsosn'];
        $this->parameterBagColumns = $this->parameterBagColumnsCSTCSOSN;
        $rows = $request->getFilterCriteria();
        $NRORG = $rows->getConditions()[0]['value'];
        $CDFILIAL = $rows->getConditions()[1]['value'];
        $CDIMPOSTO= $rows->getConditions()[2]['value'];
        $impostosCST = $this->ParaVendasImposto->getTipoImposto($CDFILIAL, $NRORG, $CDIMPOSTO);
        
        if (empty($impostosCST)) {
            if($CDIMPOSTO==99){
                $impostosCSOSN = array(
                    '0' => array(
                        'CDSITUTRIB' => '500', 
                        'DSSITUTRIB' => 'ICMS cobrado anteriormente por substituição tributária (substituído) ou por antecipação'
                    )
                );
                $response->addDataSet(new DataSet($this->dataSourceName, $impostosCSOSN));
            }
            else{
            $impostosCSOSN = array(
                '0' => array(
                    'CDSITUTRIB' => '102', 
                    'DSSITUTRIB' => 'Tributada pelo Simples Nacional sem permissão de crédito'
                ),
                '1' => array(
                    'CDSITUTRIB' => '103', 
                    'DSSITUTRIB' => 'Isenção do ICMS no Simples Nacional para faixa de receita bruta'
                ),
                '2' => array(
                    'CDSITUTRIB' => '300', 
                    'DSSITUTRIB' => 'Imune'
                ),
                '3' => array(
                    'CDSITUTRIB' => '400', 
                    'DSSITUTRIB' => 'Não Tributada pelo Simples Nacional'
                ),
                '4' => array(
                    'CDSITUTRIB' => '900', 
                    'DSSITUTRIB' => 'Outros'
                )
            );
        }
            $response->addDataSet(new DataSet($this->dataSourceName, $impostosCSOSN));
        }
        else{
         if($CDIMPOSTO==99){
             $this->dataSourceName = $this->dataSourceNames['selectCstcsosnImpoSubsTrib'];
             $response->addDataSet(new DataSet($this->dataSourceName, $impostosCST));
         }
         else{
            $response->addDataSet(new DataSet($this->dataSourceName, $impostosCST));
         }
        }
    }
    
    public function selectCST(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $request->getFilterCriteria()->getConditions();
        $params = [];
            foreach ($conditions as $value) {
                $params[$value['columnName']] = $value['value'];
            }
             $result = $this->ParaVendasImposto->verificarCaixaNFC($params);
             
             unset($conditions[1]);
          if(!empty($result)){
            $this->dataSourceName = $this->dataSourceNames['selectCstSat'];
            $this->parameterBagColumns = $this->parameterBagColumnsCST;
              $newRequest = new DTO\Request\Filter (
                new FilterCriteria(
                    $this->dataSourceName,
                    $conditions,
                    $request->getFilterCriteria()->getPage()
                ),
                $request->getMethod(),
                $request->getRoutePath(),
                $request->getUserId()
            );
            parent::find($newRequest, $response);
              
          }
          else
            $this->dataSourceName = $this->dataSourceNames['selectCst'];
            $this->parameterBagColumns = $this->parameterBagColumnsCST;
              $newRequest = new DTO\Request\Filter (
                new FilterCriteria(
                    $this->dataSourceName,
                    $conditions,
                    $request->getFilterCriteria()->getPage()
                ),
                $request->getMethod(),
                $request->getRoutePath(),
                $request->getUserId()
            );
            parent::find($newRequest, $response);
    }
    
    public function selectAliquotaCONFINS(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['selectAliCONFINS'];
        $this->parameterBagColumns = $this->parameterBagColumnsCONFINS_PIS;
        parent::find($request, $response);
    }
    
    public function selectAliquotaPIS(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['selectAliPIS'];
        $this->parameterBagColumns = $this->parameterBagColumnsCONFINS_PIS;
        parent::find($request, $response);
    }
    
    public function selectCodCEST(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['selectCEST'];
        $this->parameterBagColumns = $this->parameterBagColumnsCEST;
        parent::find($request, $response);
    }
    
    public function findSelectFieldImpostoProduto(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNames['selectImpostoProduto'];
        $this->parameterBagColumns = $this->parameterBagColumnsSelectImpostoProduto;
        parent::find($request, $response);
    }
    
    public function findProdutosNivel(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName = $this->dataSourceNames['ProdutosRepoImpostos'];
        $this->parameterBagColumns = $this->parameterBagColumnsImpostoProduto;
         
        $conditions = $request->getFilterCriteria()->getConditions();
        $params = [];
        foreach ($conditions as $value) {
            $params[$value['columnName']] = $value['value'];
        }
        if(array_key_exists('CDARVPROD', $params)) {
            $params['CDARVPROD'] = str_replace("%", "", $params['CDARVPROD']) . '%';
            $params['TCDARVPROD'] = null;

            $filterCriteria = $this->createFilterCriteria($params);
            
            $result = $this->ParaVendasImposto->findProdutosNivel($params);
            $response->addDataSet(new DataSet($this->dataSourceName, $result));
        } else {
            $params['TCDARVPROD'] = 'T';
            $params['CDARVPROD'] = null;
            $params['LIMIT_CDARVPROD'] = 0;

            $filterCriteria = $this->createFilterCriteria($params);
            $result = $this->ParaVendasImposto->findProdutosNivel($params);
            $response->addDataSet(new DataSet($this->dataSourceName, $result));

        }
        
    }
    
    public function generateAliquote (DTO\Request\Filter $request, DTO\Response $response) {
       try {
            $filter = $request->getFilterCriteria()->getConditions();
            $row["CDFILIAL"] = $filter[0]["value"];
            
            $bool = $this->ParaVendasImposto->generateAliquote($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function buildParamValue ($arr) {
        return array_reduce($arr, function($accumulator, $element) {
            return $accumulator."|".$element;
        }, "")."|";
    }
    
    public function save(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceName);
            $persistedRows = $this->dataSourceManager->persist($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceName, $persistedRows));
            $nrPersistedRows = count($persistedRows);
        } catch (\Exception $e) {
            $response->setCriticalError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
}