<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities\Query;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class ExportPriceChartService {
    // exportação para filiais sem alteração na vigência das tabelas
    const EXPORT_MULTFILI  = "E_MULTFILI";
    // exportação para filial e tabela selecionada
    const EXPORT_FILIPCSCT = "E_FILIPC";
    // exportação para filial e nova tabela de preço
    const EXPORT_FILINEWPC = "E_FILINEWPC";

    // todos os produtos 
    const T_PRODUCT = "T";

    // exportação concluída
    const SUCCESS_PC = "SUCCESS";
    // tabela já cadastrada para filial
    const ALREADY_PC = "ALREADY";
    // erro na exportação
    const ERROR_PC = "ERROR";
    // sem vigência ativa
    const WITHOUTVIG_PC = "WITHOUTVIG";
    // sem produtos na tabela destino
    const WITHOUTPROD_PC = "WITHOPROD";
    
    public function __construct(EntityManager $entityManager)  {
        $this->entityManager = $entityManager;
    }
    
    public function getPRECOITEMDIA($dataExport){
        $data = $dataExport['DATA'];
        if(is_array($data['CDFILIALDES'])){
            foreach($data['CDFILIALDES'] as $cdfilial){
                $paramsQuery = array(
                    'CDFILIAL'   => $cdfilial,
                    'CDTABEPREC' => $data['CDTABEPRECDES'],
                    'CDTABEPRECORI' => $data['CDTABEPRECORI'],
                    'CDFILIALORI' => $data['CDFILIALORI'],
                    'CDPRODUTO'  => implode('_', $data['CDPRODUTO']),
                    'TCDPRODUTO' => $data['TCDPRODUTO'],
                    'NRORG'      => $data['NRORG']
                );
                
                if($data['KEEP_PRECO'] == 'S'){
                    return $this->entityManager->getConnection()->fetchAll(self::FIND_ITEM_PRECODIA_KEEP_PRICE, $paramsQuery);
                } else {
                    return $this->entityManager->getConnection()->fetchAll(self::FIND_ITEM_PRECODIA, $paramsQuery);
                }
            }
        }else{
            $paramsQuery = array(
                'CDFILIAL'   => $data['CDFILIALDES'],
                'CDTABEPREC' => $data['CDTABEPRECDES'],
                'CDTABEPRECORI' => $data['CDTABEPRECORI'],
                'CDFILIALORI' => $data['CDFILIALORI'],
                'CDPRODUTO'  => implode('_', $data['CDPRODUTO']),
                'TCDPRODUTO' => $data['TCDPRODUTO'],
                'NRORG'      => $data['NRORG']
            );
            
            if($data['KEEP_PRECO'] == 'S'){
                return $this->entityManager->getConnection()->fetchAll(self::FIND_ITEM_PRECODIA_KEEP_PRICE, $paramsQuery);
            } else {
                return $this->entityManager->getConnection()->fetchAll(self::FIND_ITEM_PRECODIA, $paramsQuery);
            }
        }
    }
    
    public function getPRECOITEM($dataExport){
        $data   = $dataExport['DATA'];
        $paramsQuery = array(
            'CDFILIAL'   => $data['CDFILIALDES'],
            'CDFILIALORI'   => $data['CDFILIALORI'],
            'CDTABEPREC' => $data['CDTABEPRECDES'],
            'CDTABEPRECORI' => $data['CDTABEPRECORI'],
            'CDPRODUTO'  => implode('_', $data['CDPRODUTO']),
            'TCDPRODUTO' => $data['TCDPRODUTO'],
            'NRORG'      => $data['NRORG'],
            'DTINIVGPREC' => $data['DTINIVGPREC']
        );
        
        return $this->entityManager->getConnection()->fetchAll(self::FIND_ITEM_PRECO, $paramsQuery);
        
    }
    
    public function setPRECOITEMDIA($backupPrice){
        $i = 0;
        foreach($backupPrice as $data){
            $params = array(
                'CDFILIAL' => $data['CDFILIAL'],
                'CDTABEPREC' => $data['CDTABEPREC'],
                'DTINIVGPREC' => $data['DTINIVGPREC'],
                'CDPRODUTO' => $data['CDPRODUTO'],
                'CDPRPAITABPR' => $data['CDPRPAITABPR'],
                'NRDIASEMANPR' => $data['NRDIASEMANPR'],
                'HRINIPRECDIA' => $data['HRINIPRECDIA'],
                'HRFINPRECDIA' => $data['HRFINPRECDIA'],
                'VRPRECODIA' => $data['VRPRECODIA'],
                'IDPERVALORPR' => $data['IDPERVALORPR'],
                'IDDESCACREPR' => $data['IDDESCACREPR'],
                'DTINIVALPREC' => $data['DTINIVALPREC'],
                'DTFINVALPREC' => $data['DTFINVALPREC'],
                'DTULTATUITPD' => $data['DTULTATUITPD'],
                'CDTIPOCONSPD' => $data['CDTIPOCONSPD'],
                'IDVISUACUPOM' => $data['IDVISUACUPOM'],
                'NRORG' => $data['NRORG'],
                'DTINCLUSAO' => $data['DTINCLUSAO'],
                'DTULTATU' => $data['DTULTATU'],
                'NRORGINCLUSAO' => $data['NRORGINCLUSAO'],
                'CDOPERINCLUSAO' => $data['CDOPERINCLUSAO'],
                'NRORGULTATU' => $data['NRORGULTATU'],
                'CDOPERULTATU' => $data['CDOPERULTATU'],
                'IDATIVO' => $data['IDATIVO'],
                'CALCDESCONTOVRUNITARIO' => $data['CALCDESCONTOVRUNITARIO'],
                'NRTIPOPRECO' => $data['NRTIPOPRECO'],
                'VRPRECODIF' => $data['VRPRECODIF']
            );
            $this->entityManager->getConnection()->executeQuery(self::SET_ITEM_PRECODIA, $params);
            
            $i++;
        }
        return $i;
    }
    
    public function setPRECOITEM($backupPrice){
        foreach($backupPrice as $data){
            $params = array(
                'CDFILIAL'       => $data['CDFILIAL'],
                'CDTABEPREC'     => $data['CDTABEPREC'],
                'DTINIVGPREC'    => $data['DTINIVGPREC'],
                'CDPRODUTO'      => $data['CDPRODUTO'],
                'CDPRPAITABPR'   => $data['CDPRPAITABPR'],
                'VRPRECITEM'     => $data['VRPRECITEM'],
                'VRPRECITEMCL'   => $data['VRPRECITEMCL'],
                'VRPRECMAXITE'   => $data['VRPRECMAXITE'],
                'IDPRECVARIA'    => $data['IDPRECVARIA'],
                'VRPRESUGITEM'   => $data['VRPRESUGITEM'],
                'VRCUSTITEM'     => $data['VRCUSTITEM'],
                'VRMKUPITEM'     => $data['VRMKUPITEM'],
                'IDPRODPROMOC'   => $data['IDPRODPROMOC'],
                'DTULTATUITPR'   => $data['DTULTATUITPR'],
                'IDEXIPRECOSITE' => $data['IDEXIPRECOSITE'],
                'NMPRODUTOSITE'  => $data['NMPRODUTOSITE'],
                'NRORG'          => $data['NRORG'],
                'DTINCLUSAO'     => $data['DTINCLUSAO'],
                'DTULTATU'       => $data['DTULTATU'],
                'NRORGINCLUSAO'  => $data['NRORGINCLUSAO'],
                'CDOPERINCLUSAO' => $data['CDOPERINCLUSAO'],
                'NRORGULTATU'    => $data['NRORGULTATU'],
                'CDOPERULTATU'   => $data['CDOPERULTATU'],
                'IDATIVO'        => $data['IDATIVO'],
                'HRINIVENPROD'   => $data['HRINIVENPROD'],
                'HRFIMVENPROD'   => $data['HRFIMVENPROD']
            );
            $this->entityManager->getConnection()->executeQuery(self::SET_ITEM_PRECO, $params);
        }
        
    }
    
    public function exportPriceChart($dataExport){
        // seleciona qual tipo de exportação será realizada
        $status    = null;
        $data      = $dataExport['DATA'];
        $procedure = null;
        $retorno   = '';
        $product   = [];
        $unit      = [];
        
        try {
            self::controlTransaction('begin');            
        } catch (Exception $e) {
            return self::ERROR_PC;
        }
        
        if($dataExport['TYPE'] == 'E_MULTFILI') {
            $data['CDFILIALDES'] = implode('_', $data['CDFILIALDES']).'_';
        }
        
        if(!array_key_exists ('CDTABEPRECNEW', $data) && !array_key_exists ('NMTABEPRECNEW', $data) ) {
            $data['CDTABEPRECNEW'] = '';
            $data['NMTABEPRECNEW'] = '';
        }
        
        $data['CDPRODUTO'] = implode('_', $data['CDPRODUTO']).'_';
        
        $params = [];
        
        $result = false;
        
        try {
            if($data['CDPRODUTO'] != null) {
                $params = array(
                    'CDFILIAL'       => $data['CDFILIALDES'],
                    'CDTABEPREC'     => $data['CDTABEPRECDES'],
                    'CDTABEPRECNEW'  => $data['CDTABEPRECNEW'],
                    'DTINIVGPREC'    => $data['DTINIVGPREC'],
                    'NRORG'          => $data['NRORG']
                );
                
                if($dataExport['TYPE'] == 'E_MULTFILI') {
                    $inExecution = $this->entityManager->getConnection()->fetchAll(self::GET_PRODEXPOTACAOPR_MULTI, $params);
                    $params['CDTABEPREC'] = NULL;
                    $params['DTINIVGPREC'] = NULL;
                } elseif($dataExport['TYPE'] == 'E_FILIPC') {
                    $inExecution = $this->entityManager->getConnection()->fetchAll(self::GET_PRODEXPOTACAOPR_FILI, $params);
                } else {
                    $inExecution = $this->entityManager->getConnection()->fetchAll(self::GET_PRODEXPOTACAOPR_NEW, $params);
                    $params['CDTABEPREC'] = $params['CDTABEPRECNEW'];
                }
                
                $product = explode("_", $data['CDPRODUTO']);
                $unit = explode("_", $params['CDFILIAL']);
            
                if(empty($inExecution)) {
                    foreach($product as $produto) {
                        foreach($unit as $filial) {
                            $params['CDPRODUTO'] = $produto;
                            $params['CDFILIAL'] = $filial;
                            if ($params['CDPRODUTO'] != null && $params['CDFILIAL'] != null) {
                              $this->entityManager->getConnection()->executeQuery(self::INSERT_PRODEXPOTACAOPR, $params);  
                            }
                        }
                    }
                    
                    $data['CDPRODUTO'] = '';
                } else {
                    throw new \Exception("Uma exportação para a mesma tabela está sendo realizada!");
                    self::controlTransaction('rollback');
                }
            }
            
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'EXPORTA_TBPRECO');
            
            $procedure->addParam(new Param('P_CDFILIALDES'   ,   Param::PARAM_INPUT , $data['CDFILIALDES']         , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_CDFILIALORI'   ,   Param::PARAM_INPUT , $data['CDFILIALORI']         , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_CDTABEPRECORI' ,   Param::PARAM_INPUT , $data['CDTABEPRECORI']       , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_NRORG'         ,   Param::PARAM_INPUT , $data['NRORG']               , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_CDPRODUTO'     ,   Param::PARAM_INPUT , $data['CDPRODUTO']           , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_TCDPRODUTO'    ,   Param::PARAM_INPUT , $data['TCDPRODUTO']          , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_DATAATUAL'     ,   Param::PARAM_INPUT , $data['DATE']                , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_CDTABEPRECDES' ,   Param::PARAM_INPUT , $data['CDTABEPRECDES']       , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_CDTABEPRECNEW' ,   Param::PARAM_INPUT , $data['CDTABEPRECNEW']       , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_NMTABEPRECNEW' ,   Param::PARAM_INPUT , $data['NMTABEPRECNEW']       , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_DTINIVGPREC'   ,   Param::PARAM_INPUT , $data['DTVIGTAB']['start']   , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_DTFINVGPREC'   ,   Param::PARAM_INPUT , $data['DTVIGTAB']['end']     , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_DTVGPROD'      ,   Param::PARAM_INPUT , $data['DTVIGTAB']            , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_TYPE'          ,   Param::PARAM_INPUT , $dataExport['TYPE']          , Param::PARAM_TYPE_STR   ));
            $procedure->addParam(new Param('P_OK'            ,   Param::PARAM_OUTPUT, null                         , Param::PARAM_TYPE_STR, 5));
            
            $retorno = $procedure->execute();
            
            if ($retorno['P_OK'] == 'OK') {
                $result = true;
                self::controlTransaction('commit');
                return self::SUCCESS_PC; 
            } else if ($retorno['P_OK'] == 'ERROV') {
                self::controlTransaction('rollback');
                return self::WITHOUTVIG_PC;
            } else if ($retorno['P_OK'] == 'ERROA') {
                self::controlTransaction('rollback');
                return self::ALREADY_PC;
            } else if ($retorno['P_OK'] == 'ERROP') {
                self::controlTransaction('rollback');
                return self::WITHOUTPROD_PC;
            } else if ($retorno['P_OK'] == NULL) {
                self::controlTransaction('rollback');
                return self::ERROR_PC;
            } 
        } catch (\Exception $e) {
            self::controlTransaction('rollback');
            return self::ERROR_PC;
        }
        
        return $result;
    }
    
    public function controlTransaction($type){
    // controla transação com banco    
        try {
            switch ($type) {
                case 'begin':
                // inicia transação sem auto-commit
                    $this->entityManager->getConnection()->beginTransaction();
                    break;
                case 'commit':
                // salva transação
                    $this->entityManager->getConnection()->commit();
                    break;
                case 'rollback':
                // descarta transação
                    $this->entityManager->getConnection()->rollBack();
                    break;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function findVig($rows){
        
        $paramsQuery = array(
            "CDTABEPREC" =>      $rows['CDTABEPREC'],
            "CDFILIAL"   =>      $rows['CDFILIAL'],
            "NRORG"      =>      $rows['NRORG']
        );
        
        return $this->entityManager->getConnection()->fetchAll(self::SELECT_VIGENGIA, $paramsQuery);
        
    }
    
    /*public function exportPriceChart($dataExport){
    // seleciona qual tipo de exportação será realizada
        $status = null;
        $data   = $dataExport['DATA'];
        
        try {
            self::controlTransaction('begin');            
        } catch (Exception $e) {
            return self::ERROR_PC;
        }
        
        
        $params = array(
            ':NRORG'         => $data['NRORG'],
            ':CDTABEPRECDES' => $data['CDTABEPRECDES'],
            ':CDTABEPRECORI' => $data['KEEP_PRECO'] == 'S' ?  $data['CDTABEPRECORI'] : $data['CDTABEPRECDES'],
            ':CDFILIALDES'   => $data['CDFILIALDES'],
            ':CDFILIALORI'   => $data['KEEP_PRECO'] == 'S' ?  $data['CDFILIALORI'] : $data['CDFILIALDES']
        );
           
        if(!isset($data['CDPRODUTO'])){
            $data['CDPRODUTO'] = array();
        }
        if(gettype($data['CDFILIALDES']) == 'array' && count($data['CDPRODUTO']) == 0){
            foreach ($data['CDFILIALDES'] as $CDFILIAL) {
                if($data['KEEP_PRECO'] != 'S'){
                    $params[':CDFILIALORI'] = $CDFILIAL;
                    
                }
                $params[':CDFILIALDES'] = $CDFILIAL;
                $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEM_PRECO, $params);
            }
        } else if(count($data['CDPRODUTO']) > 0 &&  !!$data['CDTABEPRECDES']){
            foreach($data['CDPRODUTO'] as $cdproduto ){
                $params[':CDPRODUTO'] = $cdproduto;
                $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEM_PRECO_PROD, $params);
            }
        } else if (gettype($data['CDFILIALDES']) == 'array' && count($data['CDPRODUTO']) > 0){
            foreach ($data['CDFILIALDES'] as $CDFILIAL) {
                $params[':CDFILIALDES'] = $CDFILIAL;
                if($data['KEEP_PRECO'] != 'S'){
                    $params[':CDFILIALORI'] = $CDFILIAL;
                }
                foreach($data['CDPRODUTO'] as $cdproduto ){
                    $params[':CDPRODUTO'] = $cdproduto;
                    $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEM_PRECO_PROD, $params);
                }
                
            }
        }
        else {
            $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEM_PRECO, $params);
        }
        
        switch ($dataExport['TYPE']) {
            
            case self::EXPORT_MULTFILI:
                $status = self::exportMultFili($data);
                break;

            case self::EXPORT_FILIPCSCT:
                $status = self::exportFilialPriceChartSelect($data);
                break;

            case self::EXPORT_FILINEWPC:
                $status = self::exportFilialNewPriceChart($data);
                break;
        }

        return $status;
    }

    public function exportMultFili($data){
        $paramsQuery  = Array();
        $prodValidity = Array();
        $desFiliPC    = Array();

        try {
            if($data['TCDPRODUTO'] == 'T'){
                // delete da ITEMPRECODIA e ITEMPRECO os produtos da filial de destino
                self::formatFili($paramsQuery, $data);
                if($data['DELETE_PRECODIA'] == 'S'){
                    $this->entityManager->getConnection()->executeQuery(self::DELETE_ALLITEMPRECODIA, $paramsQuery);
                }
                $this->entityManager->getConnection()->executeQuery(self::DELETE_ALLITEMPRECO, $paramsQuery);
                
                // seleciona as filiais de destino e suas respectivas tabelas e vigências
                self::formatFiliDes($paramsQuery, $data);
                $desFiliPC = $this->entityManager->getConnection()->fetchAll(self::GET_FILITABEVEND, $paramsQuery);
                foreach ($desFiliPC as $desPC) {
                    // insere na ITEMPRECO e ITEMPRECODIA os produtos nas tabelas de preço de acordo com os registros da tabela origem
                    self::formatItemPreco($paramsQuery, $data, $desPC);
                    $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECOWITHSELECT, $paramsQuery);
                    if($data['EXPORT_PRECODIA'] === 'S')
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECODIAWITHSELECT, $paramsQuery);
                }
            }else{
                // delete da ITEMPRECODIA e ITEMPRECO os produtos da filial de destino
                self::formatFiliProd($paramsQuery, $data);
                if($data['DELETE_PRECODIA'] == 'S'){
                    $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEMPRECODIA_MULTIFILI, $paramsQuery);
                }
                $this->entityManager->getConnection()->executeQuery(self::DELETE_ITEMPRECO_MULTIFILI, $paramsQuery);
                // seleciona as filiais de destino e suas respectivas tabelas e vigências
                self::formatFiliDes($paramsQuery, $data);
                $desFiliPC = $this->entityManager->getConnection()->fetchAll(self::GET_FILITABEVEND, $paramsQuery);
                foreach ($desFiliPC as $desPC) {
                    // insere na ITEMPRECO e ITEMPRECODIA os produtos nas tabelas de preço de acordo com os registros da tabela origem
                    self::formatItemPrecoProduct($paramsQuery, $data, $desPC);
                    $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECOWITHSELECTPROD, $paramsQuery);
                    if($data['EXPORT_PRECODIA'] === 'S')
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECODIAWITHSELECTPROD, $paramsQuery);
                }
            }
            
            if(empty($desFiliPC[0]['DTINIVGPRECORI'])){
                self::controlTransaction('rollback');
                return self::WITHOUTVIG_PC;
            }else{
                self::controlTransaction('commit');
                return self::SUCCESS_PC;
            }
        } catch (Exception $e) {
            self::controlTransaction('rollback');
            return self::ERROR_PC;
        }
    }

    public function exportFilialPriceChartSelect($data){
        // modifica tabela de preço de destino para exportação
        $paramsQuery = Array();
        try {
            self::formatFiliDesProduct($paramsQuery, $data);
            $CDPRODUTO = explode("_",$paramsQuery['CDPRODUTO']);
            foreach ($CDPRODUTO as $value) {
                $paramsQuery['CDPRODUTO'] = $value;
                if($data['DELETE_PRECODIA'] == 'S')
                    $this->entityManager->getConnection()->executeQuery(self::DELETE_PRODUCTITEMPRECODIA, $paramsQuery);    
                //$this->entityManager->getConnection()->executeQuery(self::DELETE_PRODUCTITEMPRECO, $paramsQuery);  
            }
            $existProdutoItemPreco = $this->entityManager->getConnection()->fetchAll(self::EXIST_PRODUTO_ITEMPRECO);
            $existProdutoItemPrecoDia = $this->entityManager->getConnection()->fetchAll(self::EXIST_PRODUTO_ITEMPRECODIA);
            // caso a exportação seja para todos os produtos, exclui as vigência na TABEVEND
            if ($data['TCDPRODUTO'] == self::T_PRODUCT){
                self::formatTabeVend($paramsQuery, $data);
                $this->entityManager->getConnection()->executeQuery(self::DELETE_TABEVENDWITHCDTABEPREC, $paramsQuery);  
            }elseif($existProdutoItemPreco[0]['NUM'] == 0 && $existProdutoItemPrecoDia[0]['NUM'] == 0){
                self::formatTabeVend($paramsQuery, $data);
                $this->entityManager->getConnection()->executeQuery(self::DELETE_TABEVENDWITHCDTABEPREC, $paramsQuery);
            }
            // continua exportação
            if((self::exportFilialPriceChart($data)) == self::WITHOUTVIG_PC){
                self::controlTransaction('rollback');
                return self::WITHOUTVIG_PC;
            }else{
                self::controlTransaction('commit');
                return self::SUCCESS_PC;
            }
        } catch (Exception $e) {
            self::controlTransaction('rollback');
            return self::ERROR_PC;
        }
    }

    public function exportFilialNewPriceChart($data){
        // cria nova tabela de preço para filial de destino
        $paramsQuery = Array();
        $tabeprec    = Array();
        
        try {
            // verica se tabela de preço já existe para filial destino
            self::formatTabePrec($paramsQuery, $data);
            $tabeprec = $this->entityManager->getConnection()->fetchAll(self::GET_TABEPRECFROMCDTABEPREC, $paramsQuery);
            
            if (empty($tabeprec)){
                $this->entityManager->getConnection()->executeQuery(self::INSERT_TABEPRECEXP, $paramsQuery);
                $data['CDTABEPRECDES'] = $data['CDTABEPRECNEW'];
                // continua exportação
                self::exportFilialPriceChart($data);

                self::controlTransaction('commit');
                return self::SUCCESS_PC;                
            }
            else {
                self::controlTransaction('rollback');
                return self::ALREADY_PC;                
            }
        } catch (Exception $e) {
            self::controlTransaction('rollback');
            return self::ERROR_PC;
        }
    }

    public function exportFilialPriceChart($data){
        $paramsQuery = Array();
        $tabeVend    = Array();
        try {
            if ($data['TCDPRODUTO'] == self::T_PRODUCT){
                // exportar todos os produtos, clona a tabela de preço origem com suas vigências
                self::formatIncTProductT($paramsQuery, $data);
                if(array_key_exists('DTVIGTAB', $data) && $data['DTVIGTAB']){
                    self::formatParamsQueryToVigDest($paramsQuery, $data);
                    $this->entityManager->getConnection()->executeQuery(self::INSERT_TABEVENDFROMSELECTWITHVIG, $paramsQuery);
                } else {
                    $this->entityManager->getConnection()->executeQuery(self::INSERT_TABEVENDFROMSELECT, $paramsQuery);
                }
                if(array_key_exists('DTVIGTAB', $data) && $data['DTVIGTAB']){
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECOFROMSELECTWITHVIG, $paramsQuery);
                    } else {
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECOFROMSELECT, $paramsQuery);
                    }
                
                if($data['EXPORT_PRECODIA'] == 'S'){
                    if(array_key_exists('DTVIGTAB', $data) && $data['DTVIGTAB']){
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECODIAFROMSELECTWITHVIG, $paramsQuery);
                    } else {
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECODIAFROMSELECT, $paramsQuery);
                    }
                }
            }
            else {
                // exportar lista de produtos
                self::formatTabeVend($paramsQuery, $data);
                
                $tabeVend = $this->entityManager->getConnection()->fetchAll(self::GET_TABEVEND, $paramsQuery); 

                if (empty($tabeVend)){
                    // se não existir vigência na tabela de destino, as vigências são clonadas da tabela origem
                    self::formatIncTProductT($paramsQuery, $data);
                    if(array_key_exists('DTVIGTAB', $data) && $data['DTVIGTAB']){
                        self::formatParamsQueryToVigDest($paramsQuery, $data);
                        
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_TABEVENDFROMSELECTWITHVIG, $paramsQuery);
                    } else {
                        $this->entityManager->getConnection()->executeQuery(self::INSERT_TABEVENDFROMSELECT, $paramsQuery);
                    }
                    // insere na ITEMPRECO e ITEMPRECODIA a lista de produtos nas tabelas de preço de acordo com os registros da tabela origem
                    self::formatIncTProducL($paramsQuery, $data);
                    $CDPRODUTO = explode("_",$paramsQuery['CDPRODUTO']);
                    
                    foreach ($CDPRODUTO as $value) {
                        $paramsQuery['CDPRODUTO'] = $value;
                        
                        if(array_key_exists('DTVIGTAB', $data) && $data['DTVIGTAB']){
                            self::formatParamsQueryToVigDest($paramsQuery, $data);
                            $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECOFROMSELECTLISTPRODUCTWITHVIG, $paramsQuery);
                        } else {
                            $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECOFROMSELECTLISTPRODUCT, $paramsQuery);
                        }
                        if($data['EXPORT_PRECODIA'] == 'S'){
                            if(array_key_exists('DTVIGTAB', $data) && $data['DTVIGTAB']){
                                self::formatParamsQueryToVigDest($paramsQuery, $data);
                                $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECODIAFROMSELECTLISTPRODUCTWITHVIG, $paramsQuery);
                            } else {
                                $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECODIAFROMSELECTLISTPRODUCT, $paramsQuery);
                            }
                        }    
                        
                    }
                }
                else {
                    // se existir insere os produtos em todas as vigências da tabela de destino
                    foreach ($tabeVend as $validity) {
                        self::formatIncLProducL($paramsQuery, $data, $validity);
                        $verifyInsert = $this->entityManager->getConnection()->fetchAll(self::VERIFICA_VALIDINSERT, $paramsQuery);
                        if(!empty($verifyInsert)){
                            $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECOWITHVALIDITY, $paramsQuery);
                            if($data['EXPORT_PRECODIA'] == 'S')
                                $this->entityManager->getConnection()->executeQuery(self::INSERT_ITEMPRECODIAWITHVALIDITY, $paramsQuery);
                        }else{
                            return self::WITHOUTVIG_PC;
                        }
                    
                    }
                }
            }
        } catch (Exception $e) {
            throw $e;            
        }
    }
    
    public function formatFili(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDFILIAL' => implode('_', $data['CDFILIALDES']).'_',
            'NRORG'    => $data['NRORG']
        );
    }

    public function formatFiliDes(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDFILIAL' => implode('_', $data['CDFILIALDES']),
            'CDFILIALORI' => $data['CDFILIALORI'],
            'KEEP_PRECO' => $data['KEEP_PRECO'],
            'NRORG'    => $data['NRORG'],
            'CDTABEPRECORI' => $data['CDTABEPRECORI'],
            'DATAATUAL'  => $data['DATE'],
        );
    }
    
    public function formatValidityProduct(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDFILIAL'   => $data['CDFILIALORI'],
            'CDTABEPREC' => $data['CDTABEPRECORI'],
            'DATAATUAL'  => $data['DATE'],
            'NRORG'      => $data['NRORG'],
            'CDPRODUTO'  => implode('_', $data['CDPRODUTO']),
            'TCDPRODUTO' => $data['TCDPRODUTO']
        );
    }

    public function formatItemPreco(&$paramsQuery, $data, $desPC){
        $paramsQuery = array(
            'CDFILIALDES'    => $desPC['CDFILIAL'],
            'CDTABEPRECDES'  => $desPC['CDTABEPREC'],
            'CDFILIALORI'    => $data['CDFILIALORI'],
            'CDTABEPRECORI'  => $data['CDTABEPRECORI'],
            'DTINIVGPRECORI' => $desPC['DTINIVGPRECORI'],
            'DTINIVGPRECDES' => $desPC['DTINIVGPREC'],
            'DTINIVALPREC'   => $desPC['DTINIVGPREC'],
            'DTFINVALPREC'   => $desPC['DTFINVGPREC'],
            'NRORG'          => $data['NRORG']
        );
    }
    
    public function formatItemPrecoProduct(&$paramsQuery, $data, $desPC){
        $paramsQuery = array(
            'CDFILIALDES'    => $desPC['CDFILIAL'],
            'CDTABEPRECDES'  => $desPC['CDTABEPREC'],
            'CDFILIALORI'    => $data['CDFILIALORI'],
            'CDTABEPRECORI'  => $data['CDTABEPRECORI'],
            'CDPRODUTO'      => implode('_', $data['CDPRODUTO']),
            'DTINIVGPRECORI' => $desPC['DTINIVGPREC'],
            'DTINIVGPRECDES' => $desPC['DTINIVGPREC'],
            'DTINIVALPREC'   => $desPC['DTINIVGPREC'],
            'DTFINVALPREC'   => $desPC['DTFINVGPREC'],
            'NRORG'          => $data['NRORG']
        );
    }

    public function formatTabePrec(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDFILIAL'   => $data['CDFILIALDES'],
            'CDTABEPREC' => $data['CDTABEPRECNEW'],
            'NMTABEPREC' => $data['NMTABEPRECNEW'],
            'NRORG'      => $data['NRORG']
        );
    }

    public function formatFiliDesProduct(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDFILIAL'   => $data['CDFILIALDES'],
            'CDTABEPREC' => $data['CDTABEPRECDES'],
            'CDPRODUTO'  => implode('_', $data['CDPRODUTO']),
            'TCDPRODUTO' => $data['TCDPRODUTO'],
            'NRORG'      => $data['NRORG']
        );
    }

    public function formatTabeVend(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDFILIAL'   => $data['CDFILIALDES'],
            'CDTABEPREC' => $data['CDTABEPRECDES'],
            'NRORG'      => $data['NRORG']
        );
    }
    
    public function formatFiliProd(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDFILIAL'   => implode('_', $data['CDFILIALDES']),
            'CDPRODUTO' => implode('_', $data['CDPRODUTO']),
            'NRORG'      => $data['NRORG']
        );
    }

    public function formatIncTProductT(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDFILIALDES'   => $data['CDFILIALDES'],
            'CDTABEPRECDES' => $data['CDTABEPRECDES'],
            'CDFILIALORI'   => $data['CDFILIALORI'],
            'CDTABEPRECORI' => $data['CDTABEPRECORI'],            
            'NRORG'         => $data['NRORG']
        );
    }

    public function formatIncTProducL(&$paramsQuery, $data){
        $paramsQuery = array(
            'CDFILIALDES'   => $data['CDFILIALDES'],
            'CDTABEPRECDES' => $data['CDTABEPRECDES'],
            'CDFILIALORI'   => $data['CDFILIALORI'],
            'CDTABEPRECORI' => $data['CDTABEPRECORI'],
            'CDPRODUTO'     => implode('_', $data['CDPRODUTO']),            
            'NRORG'         => $data['NRORG']
        );
    }

    public function formatIncLProducL(&$paramsQuery, $data, $validity){
        $paramsQuery = array(
            'CDFILIALDESC'  => $data['CDFILIALDES'],
            'CDTABEPRECDES' => $data['CDTABEPRECDES'],
            'DTINIVGPREC'   => $validity['DTINIVGPREC'],
            'CDFILIALORI'   => $data['CDFILIALORI'],
            'CDTABEPRECORI' => $data['CDTABEPRECORI'],
            'CDPRODUTO'     => implode('_', $data['CDPRODUTO']),            
            'NRORG'         => $data['NRORG']
        );
    }
    
    private function formatParamsQueryToVigDest(&$paramsQuery, $data){
        $paramsQuery[':DTVGPROD']    = $data['DTINIVGPREC'];
        $paramsQuery[':DTINIVGPREC'] = $data['DTVIGTAB']['start'];
        $paramsQuery[':DTFINVGPREC'] = $data['DTVIGTAB']['end'];
        $paramsQuery[':NRORG']       = $data['NRORG'];
    }*/
    
    const GET_PRODEXPOTACAOPR_MULTI = "
        SELECT 
            * 
        FROM 
            PRODEXPOTACAOPR 
        WHERE 
            (INSTR(:CDFILIAL, CDFILIAL) <> 0) AND
            NRORG = :NRORG
	";
	
    const GET_PRODEXPOTACAOPR_FILI = "
        SELECT 
            * 
        FROM 
            PRODEXPOTACAOPR 
        WHERE 
            (INSTR(:CDFILIAL, CDFILIAL) <> 0) AND 
            CDTABEPREC = :CDTABEPREC AND 
            NRORG = :NRORG
	";
	
    const GET_PRODEXPOTACAOPR_NEW = "
        SELECT 
            * 
        FROM 
            PRODEXPOTACAOPR 
        WHERE 
            (INSTR(:CDFILIAL, CDFILIAL) <> 0) AND 
            CDTABEPREC = :CDTABEPRECNEW AND
            NRORG = :NRORG
	";
	
	const INSERT_PRODEXPOTACAOPR = "
		INSERT INTO PRODEXPOTACAOPR
		    (CDFILIAL, CDPRODUTO, CDTABEPREC, NRORG)
		VALUES
		    (:CDFILIAL, :CDPRODUTO, :CDTABEPREC, :NRORG)
	";

    const EXIST_PRODUTO_ITEMPRECODIA = "
      SELECT count(CDPRODUTO) AS NUM FROM ITEMPRECODIA
      ";
    const EXIST_PRODUTO_ITEMPRECO = "
      SELECT count(CDPRODUTO) AS NUM FROM ITEMPRECO
      ";
    const DELETE_ALLITEMPRECODIA = "
        DELETE
            FROM ITEMPRECODIA I
        WHERE (INSTR(:CDFILIAL, I.CDFILIAL) <> 0)
            AND I.NRORG = :NRORG
            AND (EXISTS(SELECT 1
        FROM TABEVEND T
        WHERE T.CDFILIAL = I.CDFILIAL
            AND T.CDTABEPREC = I.CDTABEPREC
            AND T.DTINIVGPREC = I.DTINIVGPREC
            AND SYSDATE BETWEEN T.DTINIVGPREC AND T.DTFINVGPREC
            AND T.NRORG = I.NRORG))
	";
	const DELETE_ALLITEMPRECO = "
        DELETE
            FROM ITEMPRECO I
        WHERE (INSTR(:CDFILIAL, I.CDFILIAL) <> 0)
            AND I.NRORG = :NRORG
            AND (EXISTS(SELECT 1
        FROM TABEVEND T
        WHERE T.CDFILIAL = I.CDFILIAL
            AND T.CDTABEPREC = I.CDTABEPREC
            AND T.DTINIVGPREC = I.DTINIVGPREC
            AND SYSDATE BETWEEN T.DTINIVGPREC AND T.DTFINVGPREC
            AND T.NRORG = I.NRORG))
	";
	const GET_FILITABEVEND = "
		SELECT CDFILIAL, CDTABEPREC, DTINIVGPREC, DTFINVGPREC, 
		(SELECT T.DTINIVGPREC
		    FROM TABEVEND T
            WHERE (T.CDFILIAL      = :CDFILIALORI)
                AND (T.CDTABEPREC  = :CDTABEPRECORI)
                AND (:DATAATUAL BETWEEN T.DTINIVGPREC AND T.DTFINVGPREC)
                AND (T.NRORG       = :NRORG)
		) AS DTINIVGPRECORI
		FROM TABEVEND
		WHERE (INSTR(:CDFILIAL, CDFILIAL) <> 0)
			AND NRORG = :NRORG
			AND (SYSDATE BETWEEN DTINIVGPREC AND DTFINVGPREC)
	";
	
	const GET_PRODVALIDITY = "
		SELECT T.DTINIVGPREC, T.DTFINVGPREC, I.CDPRODUTO
          FROM TABEVEND T 
          LEFT JOIN ITEMPRECO I ON
           (I.CDTABEPREC  = :CDTABEPREC)
          AND (I.NRORG       = :NRORG)
          AND (I.CDFILIAL    = T.CDFILIAL   )
          AND (I.CDTABEPREC  = T.CDTABEPREC )
         AND (I.DTINIVGPREC = T.DTINIVGPREC)
          AND (I.NRORG       = T.NRORG)
          JOIN PRODUTO P ON
          (I.CDPRODUTO = P.CDPRODUTO)
          AND (I.NRORG = P.NRORG)
         WHERE (T.CDFILIAL   = :CDFILIAL  )
           AND (T.CDTABEPREC = :CDTABEPREC)
           AND (:DATAATUAL BETWEEN T.DTINIVGPREC AND T.DTFINVGPREC)
           AND T.NRORG = :NRORG
           AND P.CDNVPRODUTO IN (SELECT MAX(P.CDNVPRODUTO) FROM PRODUTO)
	";
	
	const GET_PRODVALIDITY_PROD = "
		SELECT T.DTINIVGPREC, T.DTFINVGPREC, I.CDPRODUTO
          FROM TABEVEND T 
          LEFT JOIN ITEMPRECO I ON
           (I.CDTABEPREC  = :CDTABEPREC)
          AND (I.NRORG       = :NRORG)
          AND (I.CDFILIAL    = T.CDFILIAL   )
          AND (I.CDTABEPREC  = T.CDTABEPREC )
         AND (I.DTINIVGPREC = T.DTINIVGPREC)
          AND (I.NRORG       = T.NRORG)
        JOIN PRODUTO P ON
          (I.CDPRODUTO = P.CDPRODUTO)
          AND (I.NRORG = P.NRORG)
         WHERE (T.CDFILIAL   = :CDFILIAL  )
           AND (T.CDTABEPREC = :CDTABEPREC)
           AND (:DATAATUAL BETWEEN T.DTINIVGPREC AND T.DTFINVGPREC)
           AND (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0) 
           AND T.NRORG = :NRORG
           AND P.CDNVPRODUTO IN (SELECT MAX(P.CDNVPRODUTO) FROM PRODUTO)
	";
	
	const INSERT_ITEMPRECOWITHSELECT = "
		INSERT INTO ITEMPRECO
		    (CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR,
		    VRPRECITEM, VRPRECITEMCL, IDPRECVARIA, NRORG)
		SELECT
		    :CDFILIALDES, :CDTABEPRECDES, :DTINIVGPRECDES, I.CDPRODUTO, I.CDPRPAITABPR,
		    I.VRPRECITEM, I.VRPRECITEMCL, I.IDPRECVARIA, I.NRORG
		FROM
		    ITEMPRECO I, PRODUTO R
		WHERE
		    (I.CDFILIAL    = :CDFILIALORI   ) AND
		    (I.CDTABEPREC  = :CDTABEPRECORI ) AND
		    (I.DTINIVGPREC = :DTINIVGPRECORI) AND
		    (I.NRORG       = :NRORG 		) AND
		    (R.CDPRODUTO   = I.CDPRODUTO    ) AND
		    (R.NRORG 	   = I.NRORG    	) AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S'  )
	";
	const INSERT_ITEMPRECODIAWITHSELECT = "
		INSERT INTO ITEMPRECODIA
		    (CDFILIAL, CDTABEPREC, DTINIVGPREC, DTINIVALPREC, DTFINVALPREC, CDPRODUTO, CDPRPAITABPR, NRDIASEMANPR,
		    HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD, IDVISUACUPOM, IDTPMODGERAL, IDTPMODDLV, VRPRECODIADLV, IDTPMODCMD,
		    VRPRECODIACMD, NRORG)
		SELECT
            :CDFILIALDES, :CDTABEPRECDES, :DTINIVGPRECDES, 
            CASE
                WHEN I.DTINIVALPREC <= :DTINIVALPREC 
            THEN :DTINIVALPREC
            ELSE I.DTINIVALPREC END,
            CASE
                WHEN I.DTFINVALPREC >= :DTFINVALPREC THEN :DTFINVALPREC
            ELSE I.DTFINVALPREC END,
            I.CDPRODUTO, I.CDPRPAITABPR, I.NRDIASEMANPR, I.HRINIPRECDIA, I.HRFINPRECDIA, I.VRPRECODIA, I.IDPERVALORPR,
            I.IDDESCACREPR, I.CDTIPOCONSPD, I.IDVISUACUPOM,I.IDTPMODGERAL, I.IDTPMODDLV, I.VRPRECODIADLV, I.IDTPMODCMD, I.VRPRECODIACMD
		FROM
		    ITEMPRECODIA I, PRODUTO R
		WHERE
		    (I.CDFILIAL    = :CDFILIALORI   ) AND
		    (I.CDTABEPREC  = :CDTABEPRECORI ) AND
		    (I.DTINIVGPREC = :DTINIVGPRECORI) AND
		    (I.NRORG 	   = :NRORG		    ) AND
		    (R.CDPRODUTO   = I.CDPRODUTO    ) AND
			(R.NRORG 	   = I.NRORG 	    ) AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S'  )
	";
	
	const INSERT_ITEMPRECOWITHSELECTPROD = "
		INSERT INTO ITEMPRECO
		    (CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR,
		    VRPRECITEM, VRPRECITEMCL, IDPRECVARIA, NRORG)
		SELECT
		    :CDFILIALDES, :CDTABEPRECDES, :DTINIVGPRECDES, I.CDPRODUTO, I.CDPRPAITABPR,
		    I.VRPRECITEM, I.VRPRECITEMCL, I.IDPRECVARIA, I.NRORG
		FROM
		    ITEMPRECO I, PRODUTO R
		WHERE
		    (I.CDFILIAL    = :CDFILIALORI   ) AND
		    (I.CDTABEPREC  = :CDTABEPRECORI ) AND
		    (I.DTINIVGPREC = :DTINIVGPRECORI) AND
		    (I.CDPRODUTO   = :CDPRODUTO     ) AND
		    (I.NRORG       = :NRORG 		) AND
		    ((INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0)) AND
		    (R.CDPRODUTO   = I.CDPRODUTO    ) AND
		    (R.NRORG 	   = I.NRORG    	) AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S'  )
	";
	const INSERT_ITEMPRECODIAWITHSELECTPROD = "
		INSERT INTO ITEMPRECODIA
		    (CDFILIAL, CDTABEPREC, DTINIVGPREC, DTINIVALPREC, DTFINVALPREC, CDPRODUTO, CDPRPAITABPR, NRDIASEMANPR,
		    HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD, IDVISUACUPOM, NRORG)
		SELECT
            :CDFILIALDES, :CDTABEPRECDES, :DTINIVGPRECDES, 
            CASE
                WHEN I.DTINIVALPREC <= :DTINIVALPREC 
            THEN :DTINIVALPREC
            ELSE I.DTINIVALPREC END,
            CASE
                WHEN I.DTFINVALPREC >= :DTFINVALPREC
            THEN :DTFINVALPREC
            ELSE I.DTFINVALPREC END,
            I.CDPRODUTO, I.CDPRPAITABPR, I.NRDIASEMANPR, I.HRINIPRECDIA, I.HRFINPRECDIA, I.VRPRECODIA, I.IDPERVALORPR,
            I.IDDESCACREPR, I.CDTIPOCONSPD, I.IDVISUACUPOM,I.IDTPMODGERAL, I.IDTPMODDLV, I.VRPRECODIADLV, I.IDTPMODCMD, I.VRPRECODIACMD
		FROM
		    ITEMPRECODIA I, PRODUTO R
		WHERE
		    (I.CDFILIAL    = :CDFILIALORI   ) AND
		    (I.CDTABEPREC  = :CDTABEPRECORI ) AND
		    (I.DTINIVGPREC = :DTINIVGPRECORI) AND
		    (I.CDPRODUTO   = :CDPRODUTO     ) AND
		    (I.NRORG 	   = :NRORG		    ) AND
		    (R.CDPRODUTO   = I.CDPRODUTO    ) AND
		    ((INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0)) AND
			(R.NRORG 	   = I.NRORG 	    ) AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S'  )
	";
	
	const DELETE_PRODUCTITEMPRECODIA = "
		DELETE
    FROM ITEMPRECODIA
   WHERE (CDFILIAL    = :CDFILIAL)   AND
       (CDTABEPREC  = :CDTABEPREC) AND
       ((CDPRODUTO = :CDPRODUTO) OR (:TCDPRODUTO = 'T')) AND
       (NRORG = :NRORG)
	";
	
	
	const FIND_ITEM_PRECO = "
    SELECT *
        FROM ITEMPRECO 
       WHERE (CDFILIAL    = :CDFILIAL)   AND
           (CDTABEPREC  = :CDTABEPREC) AND
           ((CDPRODUTO = :CDPRODUTO) OR (:TCDPRODUTO = 'T')) AND
           (NRORG = :NRORG)
           AND DTINIVGPREC = :DTINIVGPREC
           AND CDPRODUTO NOT IN (SELECT CDPRODUTO FROM ITEMPRECO WHERE CDFILIAL =:CDFILIALORI
                                        AND CDTABEPREC = :CDTABEPRECORI
                                        AND DTINIVGPREC = :DTINIVGPREC)
                                        
    	";
	
	const FIND_ITEM_PRECODIA = "
    SELECT DISTINCT ITD.*
        FROM ITEMPRECODIA ITD
        JOIN ITEMPRECO IT ON
        IT.CDPRODUTO = ITD.CDPRODUTO
       WHERE (ITD.CDFILIAL    = :CDFILIAL)   AND
           (ITD.CDTABEPREC  = :CDTABEPREC) AND
           (IT.CDTABEPREC  = :CDTABEPRECORI) AND
           ((ITD.CDPRODUTO = :CDPRODUTO) OR (:TCDPRODUTO = 'T')) AND
           (ITD.NRORG = :NRORG)
    	";
    
    const FIND_ITEM_PRECODIA_KEEP_PRICE = "
                SELECT DISTINCT ITD.*
        FROM ITEMPRECODIA ITD
       WHERE (ITD.CDFILIAL    = :CDFILIAL)   AND
           (ITD.CDTABEPREC  = :CDTABEPREC) AND
           ((ITD.CDPRODUTO = :CDPRODUTO) OR (:TCDPRODUTO = 'T')) AND
           (ITD.NRORG = :NRORG)
           AND ITD.CDPRODUTO||ITD.NRDIASEMANPR NOT IN (SELECT CDPRODUTO||NRDIASEMANPR FROM ITEMPRECODIA 
           WHERE CDFILIAL    = :CDFILIALORI   AND
                 CDTABEPREC  = :CDTABEPRECORI)
    	";
	
	const DELETE_PRODUCTITEMPRECO = "
		DELETE
		FROM ITEMPRECO
		WHERE 
			(CDFILIAL   = :CDFILIAL)   AND
		    (CDTABEPREC = :CDTABEPREC) AND
		    (NRORG      = :NRORG) AND
		    ((INSTR(:CDPRODUTO, CDPRODUTO) <> 0) OR (:TCDPRODUTO = 'T')) 
	";
	const DELETE_TABEVENDWITHCDTABEPREC = "
		DELETE
		FROM TABEVEND
		WHERE 
			(CDFILIAL    = :CDFILIAL)	AND
		    (CDTABEPREC  = :CDTABEPREC) AND
		    (NRORG       = :NRORG)
	";
	const GET_TABEPRECFROMCDTABEPREC = "
		SELECT * 
		FROM TABEPREC
		WHERE 
			(CDFILIAL  = :CDFILIAL)	  AND
			(CDTABEPREC = :CDTABEPREC) AND
			(NRORG 	   = :NRORG)				 
	";
	const INSERT_TABEPRECEXP = "
		INSERT INTO TABEPREC
		    (CDFILIAL, CDTABEPREC, NMTABEPREC, NRORG)
		VALUES
		 	(:CDFILIAL, :CDTABEPREC, :NMTABEPREC, :NRORG)
	";
	
	const INSERT_TABEVENDFROMSELECTWITHVIG = "
		INSERT INTO TABEVEND
		    (CDFILIAL, CDTABEPREC, DTINIVGPREC, DTFINVGPREC, NRORG)
		VALUES
		    (:CDFILIALDES, :CDTABEPRECDES, :DTINIVGPREC, :DTFINVGPREC, :NRORG)
	";
	
	const INSERT_TABEVENDFROMSELECT = "
		INSERT INTO TABEVEND
		    (CDFILIAL, CDTABEPREC, DTINIVGPREC, DTFINVGPREC, NRORG)
		SELECT
		    :CDFILIALDES, :CDTABEPRECDES, DTINIVGPREC, DTFINVGPREC, NRORG
		FROM
		    TABEVEND
		WHERE
		    (CDFILIAL   = :CDFILIALORI)   AND
		    (CDTABEPREC = :CDTABEPRECORI) AND
		    (NRORG 		= :NRORG)
	";
	const INSERT_ITEMPRECOFROMSELECTLISTPRODUCT = "
		INSERT INTO ITEMPRECO
	  		(CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR,
	   		VRPRECITEM, VRPRECITEMCL, IDPRECVARIA, NRORG)
	 	SELECT
	   		:CDFILIALDES, :CDTABEPRECDES, I.DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR,
	   		I.VRPRECITEM, I.VRPRECITEMCL, I.IDPRECVARIA, I.NRORG
	 	FROM ITEMPRECO I, PRODUTO R
	 	WHERE
		    (I.CDFILIAL   = :CDFILIALORI)   	  AND
		    (I.CDTABEPREC = :CDTABEPRECORI) 	  AND
		    (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0) AND
		    (I.NRORG 	  = :NRORG)		     	  AND
		    (R.CDPRODUTO  = I.CDPRODUTO)     	  AND
		    (R.NRORG 	  = I.NRORG)		 	  AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S') 
	";
	
		const INSERT_ITEMPRECOFROMSELECTLISTPRODUCTWITHVIG = "
		INSERT INTO ITEMPRECO
	  		(CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR,
	   		VRPRECITEM, VRPRECITEMCL, IDPRECVARIA, NRORG)
	 	SELECT
	   		:CDFILIALDES, :CDTABEPRECDES, :DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR,
	   		I.VRPRECITEM, I.VRPRECITEMCL, I.IDPRECVARIA, I.NRORG
	 	FROM ITEMPRECO I, PRODUTO R
	 	WHERE
		    (I.CDFILIAL   = :CDFILIALORI)   	  AND
		    (I.CDTABEPREC = :CDTABEPRECORI) 	  AND
		    (I.DTINIVGPREC = :DTVGPROD)          AND
		    (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0) AND
		    (I.NRORG 	  = :NRORG)		     	  AND
		    (R.CDPRODUTO  = I.CDPRODUTO)     	  AND
		    (R.NRORG 	  = I.NRORG)		 	  AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S') 
	"; 
	
	const INSERT_ITEMPRECODIAFROMSELECTLISTPRODUCT = "
		INSERT INTO ITEMPRECODIA
	  		(CDFILIAL, CDTABEPREC, DTINIVGPREC, DTINIVALPREC, DTFINVALPREC, CDPRODUTO, CDPRPAITABPR, NRDIASEMANPR,
	   		HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD)
	 	SELECT
	   		:CDFILIALDES, :CDTABEPRECDES, I.DTINIVGPREC, I.DTINIVALPREC, I.DTFINVALPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.NRDIASEMANPR,
	   		I.HRINIPRECDIA, I.HRFINPRECDIA, I.VRPRECODIA, I.IDPERVALORPR, I.IDDESCACREPR, I.CDTIPOCONSPD
	 	FROM ITEMPRECODIA I,  PRODUTO R
	 	WHERE
		    (I.CDFILIAL   = :CDFILIALORI)   	  AND
		    (I.CDTABEPREC = :CDTABEPRECORI) 	  AND
		    (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0) AND
		    (I.NRORG 	  = :NRORG)		     	  AND
		    (R.CDPRODUTO  = I.CDPRODUTO)     	  AND
		    (R.NRORG 	  = I.NRORG)		 	  AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S') 
  	";
  	
  	const INSERT_ITEMPRECODIAFROMSELECTLISTPRODUCTWITHVIG = "
		INSERT INTO ITEMPRECODIA
	  		(CDFILIAL, CDTABEPREC, DTINIVGPREC, DTINIVALPREC, DTFINVALPREC, CDPRODUTO, CDPRPAITABPR, NRDIASEMANPR,
	   		HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD)
	 	SELECT
	   		:CDFILIALDES, :CDTABEPRECDES, :DTINIVGPREC, I.DTINIVALPREC, I.DTFINVALPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.NRDIASEMANPR,
	   		I.HRINIPRECDIA, I.HRFINPRECDIA, I.VRPRECODIA, I.IDPERVALORPR, I.IDDESCACREPR, I.CDTIPOCONSPD
	 	FROM ITEMPRECODIA I,  PRODUTO R
	 	WHERE
		    (I.CDFILIAL   = :CDFILIALORI)   	  AND
		    (I.CDTABEPREC = :CDTABEPRECORI) 	  AND
		    (I.DTINIVGPREC = :DTVGPROD)           AND
		    (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0) AND
		    (I.NRORG 	  = :NRORG)		     	  AND
		    (R.CDPRODUTO  = I.CDPRODUTO)     	  AND
		    (R.NRORG 	  = I.NRORG)		 	  AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S') 
  	";
  	
  	const INSERT_ITEMPRECOWITHVALIDITY = "
	INSERT INTO ITEMPRECO
	    (CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR, VRPRECITEM, VRPRECITEMCL, VRPRECMAXITE,
	    IDPRECVARIA, VRPRESUGITEM, VRCUSTITEM, VRMKUPITEM, IDPRODPROMOC, NRORG)	
	SELECT 
	    :CDFILIALDESC, :CDTABEPRECDES, :DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.VRPRECITEM, I.VRPRECITEMCL, I.VRPRECMAXITE,
	    I.IDPRECVARIA, I.VRPRESUGITEM, I.VRCUSTITEM, I.VRMKUPITEM, I.IDPRODPROMOC, I.NRORG
	FROM ITEMPRECO I, TABEVEND T
	WHERE
		(I.CDFILIAL        = :CDFILIALORI)
	    AND (I.CDTABEPREC  = :CDTABEPRECORI)
	    AND (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0)
	    AND (I.NRORG       = :NRORG)
	    AND (I.CDFILIAL    = T.CDFILIAL)
	    AND (I.CDTABEPREC  = T.CDTABEPREC)
	    AND (I.DTINIVGPREC = T.DTINIVGPREC)
	    AND (I.NRORG       = T.NRORG)
	    AND (SYSDATE BETWEEN I.DTINIVGPREC AND T.DTFINVGPREC)
  	";
  	const INSERT_ITEMPRECODIAWITHVALIDITY = "
  	INSERT INTO ITEMPRECODIA
   		(CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR, NRDIASEMANPR, HRINIPRECDIA, CDTIPOCONSPD,
    	HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, DTINIVALPREC, DTFINVALPREC, IDVISUACUPOM, NRORG)
	SELECT 
		:CDFILIALDESC, :CDTABEPRECDES, :DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.NRDIASEMANPR, I.HRINIPRECDIA, I.CDTIPOCONSPD,
       	I.HRFINPRECDIA, I.VRPRECODIA, I.IDPERVALORPR, I.IDDESCACREPR, I.DTINIVALPREC, I.DTFINVALPREC, I.IDVISUACUPOM, I.NRORG
  	FROM ITEMPRECODIA I, TABEVEND T
  	WHERE
		(I.CDFILIAL        = :CDFILIALORI)
	    AND (I.CDTABEPREC  = :CDTABEPRECORI)
	    AND (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0)
	    AND (I.NRORG       = :NRORG)
	    AND (I.CDFILIAL    = T.CDFILIAL)
	    AND (I.CDTABEPREC  = T.CDTABEPREC)
	    AND (I.DTINIVGPREC = T.DTINIVGPREC)
	    AND (I.NRORG       = T.NRORG)
	    AND (SYSDATE BETWEEN I.DTINIVGPREC AND T.DTFINVGPREC)
  	";
  	const GET_TABEVEND = "
		SELECT *
		FROM TABEVEND
	    WHERE 
	    	(CDFILIAL   = :CDFILIAL)  AND
	        (CDTABEPREC = :CDTABEPREC) AND
	        (NRORG 		= :NRORG)
	";
	const DELETE_ITEMPRECODIA_MULTIFILI = "
	    DELETE
        FROM ITEMPRECODIA I
       WHERE (INSTR(:CDFILIAL, I.CDFILIAL) <> 0)
         AND (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0)
         AND (I.NRORG = :NRORG)
         AND (EXISTS(SELECT 1
        FROM TABEVEND T
        WHERE T.CDFILIAL = I.CDFILIAL
            AND T.CDTABEPREC = I.CDTABEPREC
            AND T.DTINIVGPREC = I.DTINIVGPREC
            AND SYSDATE BETWEEN T.DTINIVGPREC AND T.DTFINVGPREC
            AND T.NRORG = I.NRORG))
	";
	const DELETE_ITEMPRECO_MULTIFILI = "
	    DELETE
        FROM ITEMPRECO I
       WHERE (INSTR(:CDFILIAL, I.CDFILIAL) <> 0)
         AND (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0)
         AND (I.NRORG = :NRORG)
         AND (EXISTS(SELECT 1
        FROM TABEVEND T
        WHERE T.CDFILIAL = I.CDFILIAL
            AND T.CDTABEPREC = I.CDTABEPREC
            AND T.DTINIVGPREC = I.DTINIVGPREC
            AND SYSDATE BETWEEN T.DTINIVGPREC AND T.DTFINVGPREC
            AND T.NRORG = I.NRORG))
	";
	const ADQ_TAB_ORIGIN = "
	    SELECT I.CDPRODUTO, T.DTINIVGPREC, T.DTFINVGPREC
        FROM ITEMPRECO I, TABEVEND T
       WHERE (I.CDFILIAL    = :CDFILIAL  )
         AND (I.CDTABEPREC  = :CDTABEPREC)
         AND (I.CDFILIAL    = T.CDFILIAL   )
         AND (I.CDTABEPREC  = T.CDTABEPREC )
         AND (I.DTINIVGPREC = T.DTINIVGPREC)
         AND ((INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0) OR (:TCDPRODUTO = 'T'))
	";
	
	const INSERT_ITEMPRECOFROMSELECT = "
		INSERT INTO ITEMPRECO
		    (CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR,
		    VRPRECITEM, VRPRECITEMCL, IDPRECVARIA, NRORG)
		SELECT
		    :CDFILIALDES, :CDTABEPRECDES, I.DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR,
		    I.VRPRECITEM, I.VRPRECITEMCL, I.IDPRECVARIA, I.NRORG
		FROM
		    ITEMPRECO I, PRODUTO R
	    WHERE
		    (I.CDFILIAL   = :CDFILIALORI)   AND
		    (I.CDTABEPREC = :CDTABEPRECORI) AND
		    (I.NRORG 	  = :NRORG) 		AND
		    (R.CDPRODUTO  = I.CDPRODUTO)    AND
		    (R.NRORG 	  = I.NRORG)		AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S')
	";
	
	const INSERT_ITEMPRECOFROMSELECTWITHVIG = "
		INSERT INTO ITEMPRECO
		    (CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR,
		    VRPRECITEM, VRPRECITEMCL, IDPRECVARIA, NRORG)
		SELECT
		    :CDFILIALDES, :CDTABEPRECDES, :DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR,
		    I.VRPRECITEM, I.VRPRECITEMCL, I.IDPRECVARIA, I.NRORG
		FROM
		    ITEMPRECO I, PRODUTO R
	    WHERE
		    (I.CDFILIAL   = :CDFILIALORI)   AND
		    (I.CDTABEPREC = :CDTABEPRECORI) AND
		    (I.DTINIVGPREC = :DTVGPROD)    AND
		    (I.NRORG 	  = :NRORG) 		AND
		    (R.CDPRODUTO  = I.CDPRODUTO)    AND
		    (R.NRORG 	  = I.NRORG)		AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S')
	";
	
	const INSERT_ITEMPRECODIAFROMSELECT = "
		INSERT INTO ITEMPRECODIA
		    (CDFILIAL, CDTABEPREC, DTINIVGPREC, DTINIVALPREC, DTFINVALPREC, CDPRODUTO, CDPRPAITABPR, NRDIASEMANPR,
		    HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD, NRORG)
		SELECT
		    :CDFILIALDES, :CDTABEPRECDES, I.DTINIVGPREC, I.DTINIVALPREC, I.DTFINVALPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.NRDIASEMANPR,
		    I.HRINIPRECDIA, I.HRFINPRECDIA, I.VRPRECODIA, I.IDPERVALORPR, I.IDDESCACREPR, I.CDTIPOCONSPD, I.NRORG
		FROM
		    ITEMPRECODIA I,  PRODUTO R
	    WHERE
		    (I.CDFILIAL   = :CDFILIALORI)   AND
		    (I.CDTABEPREC = :CDTABEPRECORI) AND
		    (I.NRORG 	  = :NRORG)		    AND
		    (R.CDPRODUTO  = I.CDPRODUTO)	AND
		    (R.NRORG 	  = I.NRORG)		AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S')	
	";
	
	const INSERT_ITEMPRECODIAFROMSELECTWITHVIG = "
		INSERT INTO ITEMPRECODIA
		    (CDFILIAL, CDTABEPREC, DTINIVGPREC, DTINIVALPREC, DTFINVALPREC, CDPRODUTO, CDPRPAITABPR, NRDIASEMANPR,
		    HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD, NRORG)
		SELECT
		    :CDFILIALDES, :CDTABEPRECDES, :DTINIVGPREC, I.DTINIVALPREC, I.DTFINVALPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.NRDIASEMANPR,
		    I.HRINIPRECDIA, I.HRFINPRECDIA, I.VRPRECODIA, I.IDPERVALORPR, I.IDDESCACREPR, I.CDTIPOCONSPD, I.NRORG
		FROM
		    ITEMPRECODIA I,  PRODUTO R
	    WHERE
		    (I.CDFILIAL   = :CDFILIALORI)   AND
		    (I.CDTABEPREC = :CDTABEPRECORI) AND
		    (I.DTINIVGPREC = :DTVGPROD)    AND
		    (I.NRORG 	  = :NRORG)		    AND
		    (R.CDPRODUTO  = I.CDPRODUTO)	AND
		    (R.NRORG 	  = I.NRORG)		AND
		    (NVL(R.IDPRODATIVPR,'S') = 'S')	
	";
	const VERIFICA_VALIDINSERT = "
	SELECT 
	    :CDFILIALDESC, :CDTABEPRECDES, :DTINIVGPREC, I.CDPRODUTO, I.CDPRPAITABPR, I.VRPRECITEM, I.VRPRECITEMCL, I.VRPRECMAXITE,
	    I.IDPRECVARIA, I.VRPRESUGITEM, I.VRCUSTITEM, I.VRMKUPITEM, I.IDPRODPROMOC, I.NRORG
	FROM ITEMPRECO I, TABEVEND T
	WHERE
		(I.CDFILIAL        = :CDFILIALORI)
	    AND (I.CDTABEPREC  = :CDTABEPRECORI)
	    AND (INSTR(:CDPRODUTO, I.CDPRODUTO) <> 0)
	    AND (I.NRORG       = :NRORG)
	    AND (I.CDFILIAL    = T.CDFILIAL)
	    AND (I.CDTABEPREC  = T.CDTABEPREC)
	    AND (I.DTINIVGPREC = T.DTINIVGPREC)
	    AND (I.NRORG       = T.NRORG)
	    AND (SYSDATE BETWEEN I.DTINIVGPREC AND T.DTFINVGPREC)
	";
	const DELETE_ITEM_PRECO = "
	     DELETE FROM ITEMPRECO
	        WHERE CDFILIAL  = :CDFILIALDES AND
	            CDTABEPREC   = :CDTABEPRECDES AND
	            NRORG       = :NRORG AND
	            CDPRODUTO IN (SELECT CDPRODUTO FROM ITEMPRECO 
	                            WHERE   CDFILIAL  = :CDFILIALORI AND
                        	            CDTABEPREC   = :CDTABEPRECORI AND
                        	            NRORG       = :NRORG)
	            
	";
	
	const DELETE_ITEM_PRECO_PROD = "
	     DELETE FROM ITEMPRECO
	        WHERE CDFILIAL  = :CDFILIALDES AND
	            CDTABEPREC   = :CDTABEPRECDES AND
	            CDPRODUTO = :CDPRODUTO AND
	            NRORG       = :NRORG
	";
	
	const SET_ITEM_PRECODIA = "
	INSERT INTO ITEMPRECODIA 
	        (
	            CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR, 
	            NRDIASEMANPR, HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, 
	            IDDESCACREPR, DTINIVALPREC, DTFINVALPREC, DTULTATUITPD, CDTIPOCONSPD,
	            IDVISUACUPOM, NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO,
                CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, IDATIVO, CALCDESCONTOVRUNITARIO, 
                NRTIPOPRECO, VRPRECODIF
            )
            VALUES 
            (
                :CDFILIAL, :CDTABEPREC, :DTINIVGPREC, :CDPRODUTO, :CDPRPAITABPR,
                :NRDIASEMANPR, :HRINIPRECDIA, :HRFINPRECDIA, :VRPRECODIA, :IDPERVALORPR,
                :IDDESCACREPR, :DTINIVALPREC, :DTFINVALPREC, :DTULTATUITPD, :CDTIPOCONSPD,
                :IDVISUACUPOM, :NRORG, :DTINCLUSAO, :DTULTATU, :NRORGINCLUSAO,
                :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU, :IDATIVO, :CALCDESCONTOVRUNITARIO,
                :NRTIPOPRECO, :VRPRECODIF
            )";
    
    const SET_ITEM_PRECO = "
	INSERT INTO ITEMPRECO 
	        (
	            CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR, VRPRECITEM, VRPRECITEMCL ,VRPRECMAXITE,
	            IDPRECVARIA, VRPRESUGITEM, VRCUSTITEM, VRMKUPITEM, IDPRODPROMOC, DTULTATUITPR, IDEXIPRECOSITE,
	            NMPRODUTOSITE, NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU,
	            IDATIVO, HRINIVENPROD, HRFIMVENPROD
            )
            VALUES 
            (
                :CDFILIAL, :CDTABEPREC, :DTINIVGPREC, :CDPRODUTO, :CDPRPAITABPR, :VRPRECITEM, :VRPRECITEMCL, :VRPRECMAXITE,
	            :IDPRECVARIA, :VRPRESUGITEM, :VRCUSTITEM, :VRMKUPITEM, :IDPRODPROMOC, :DTULTATUITPR, :IDEXIPRECOSITE,
	            :NMPRODUTOSITE, :NRORG, :DTINCLUSAO, :DTULTATU, :NRORGINCLUSAO, :CDOPERINCLUSAO, :NRORGULTATU, :CDOPERULTATU,
	            :IDATIVO, :HRINIVENPROD, :HRFIMVENPROD
        )";
        
        
    const SELECT_VIGENGIA = "
    SELECT TO_CHAR(DTINIVGPREC, 'DD/MM/YYYY') AS DTINIVGPREC, TO_CHAR(DTFINVGPREC, 'DD/MM/YYYY') AS DTFINVGPREC FROM TABEVEND
        WHERE NRORG = :NRORG
            AND CDFILIAL = :CDFILIAL
            AND CDTABEPREC = :CDTABEPREC";
}