<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities\Query;

class ParaGeraisExpImpostoService {

    // exporta lista de produtos
    const EXPORT_ALLPROD  = "E_ALLPROD";
    // exporta todos produtos
    const EXPORT_LISTPROD = "E_LISTPROD";
    // todos os produtos 
    const T_PRODUCT = "T";
    // exportação concluída
    const SUCCESS_PC = "SUCCESS";
    // erro na exportação
    const ERROR_PC = "ERROR";
    
    public function __construct(EntityManager $entityManager)  {
        $this->entityManager = $entityManager;
    }
  
    public function exportImpost($dataExport){
    // seleciona qual tipo de exportação será realizada
        $status = null;
        $data   = $dataExport['DATA'];
        

        try {
            self::controlTransaction('begin');            
        } catch (Exception $e) {
            return self::ERROR_PC;
        }
        switch ($dataExport['TYPE']) {

            case self::EXPORT_ALLPROD:
                $status = self::exportAllProd($data);
                break;

            case self::EXPORT_LISTPROD:
                $status = self::exportListProd($data);
                break;
        }

        return $status;
    }

    public function controlTransaction($type){
    // controla transação com banco    
        try {
            switch ($type) {
                case 'begin':
                // inicia transação sem auto-commit
                    $this->entityManager->getConnection()->beginTransaction();
                    break;
                case 'commit':
                // salva transação
                    $this->entityManager->getConnection()->commit();
                    break;
                case 'rollback':
                // descarta transação
                    $this->entityManager->getConnection()->rollBack();
                    break;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function exportAllProd($data){
        $paramsQuery  = Array();

        try {
            // busca PRODUTOS da tabela de origem
            self::formatGetProdOri($paramsQuery, $data);
            $data['CDPRODUTOORI'] = $this->entityManager->getConnection()->fetchAll(self::GET_ALL_ORIGIN_PRODUCTS, $paramsQuery);
            foreach($data['CDFILIALDES'] as $destino){
                // deleta PRODUTOS EM COMUM na tabela de destino
                foreach($data['CDPRODUTOORI'] as $produto) {
                    self::formatFiliDes($paramsQuery,$data, $destino, $produto);
                    $this->entityManager->getConnection()->executeQuery(self::DELETE_DESTINY_ALIQIMPFIS, $paramsQuery);
                }
                // insere os dados da tabela origem na tabela destino
                self::formatFiliDesOri($paramsQuery,$data, $destino);
                $this->entityManager->getConnection()->executeQuery(self::INSERT_ORIGIN_ALLALIQIMPFIS, $paramsQuery);
            }
            self::controlTransaction('commit');
            return self::SUCCESS_PC;
        } catch (Exception $e) {
            self::controlTransaction('rollback');
            return self::ERROR_PC;
        }
    }

    public function exportListProd($data){
        $paramsQuery = Array();

        try {
           self::formatFiliDesProd($paramsQuery,$data);
           $this->entityManager->getConnection()->executeQuery(self::DELETE_DESTINY_LIST_PROD, $paramsQuery); 
           // deleta o produto da tabela destino
           self::formatFiliDesProdInsert($paramsQuery,$data);
           foreach($data['CDFILIALDES'] as $destino){
               $paramsQuery['CDFILIALDES'] = $destino;
               // insere o produto da tabela origem na tabela destino
               $this->entityManager->getConnection()->executeQuery(self::INSERT_DESTINY_LIST_PROD, $paramsQuery);
           }
           self::controlTransaction('commit');
           return self::SUCCESS_PC;
        } catch (Exception $e) {
            self::controlTransaction('rollback');
            return self::ERROR_PC;
        }
    }
    
    public function formatGetProdOri(&$paramsQuery, $data){
        $paramsQuery = array(
          'CDFILIALORI' => $data['CDFILIALORI'],
          'NRORG'       => $data['NRORG']
        );
    }

    public function formatFiliDesOri(&$paramsQuery, $data, $destino){
        $paramsQuery = array(
          'CDFILIALDES' => $destino,
          'CDFILIALORI' => $data['CDFILIALORI'],
          'NRORG'    => $data['NRORG']
        );
    }
    
    public function formatFiliDes(&$paramsQuery, $data, $destino, $produto){
        $paramsQuery = array(
          'CDFILIALDES' => $destino,
          'CDPRODUTOORI'=> $produto['CDPRODUTO'],
          'NRORG'       => $data['NRORG']
        );
    }
    
    public function formatFiliDesProd(&$paramsQuery, $data){
        $paramsQuery = array(
          'CDFILIALDES'=> implode('_', $data['CDFILIALDES']),
          'NRORG'      => $data['NRORG'],
          'CDPRODUTO'  => implode('_', $data['CDPRODUTO']) 
        );  
    }
    
    public function formatFiliDesProdInsert(&$paramsQuery, $data){
        $paramsQuery = array(
          'CDFILIALDES'=> $data['CDFILIALDES'],
          'NRORG'      => $data['NRORG'],
          'CDFILIALORI' => $data['CDFILIALORI'],
          'CDPRODUTO'  => implode('_', $data['CDPRODUTO']) 
        );        
    }
    
    const GET_ALL_ORIGIN_PRODUCTS = "
    	SELECT CDPRODUTO
		  FROM ALIQIMPFIS
		 WHERE NRORG = :NRORG
		   AND CDFILIAL = :CDFILIALORI
    ";

    const DELETE_DESTINY_ALIQIMPFIS = "
      DELETE FROM ALIQIMPFIS WHERE CDFILIAL = :CDFILIALDES AND CDPRODUTO = :CDPRODUTOORI AND NRORG = :NRORG 
    ";

    const INSERT_ORIGIN_ALLALIQIMPFIS = "
      INSERT INTO ALIQIMPFIS
        ( CDFILIAL, CDPRODUTO, VRPEALIMPFIS, CDIMPOSTO, IDTPIMPOSFIS,
          IDINCIDEPISCOF, VRALIQIBPT, VRALIQIBPTES, CDCSTICMS, CDCSTPISCOF, 
          CDCFOPPFIS, VRALIQPIS, VRALIQCOFINS, CDREGRAIT, VRPERCREDUCAO, IDMODALBASECALC, 
          CDREGRAITPC, CDCEST, NRORG, VRALIQFCP, VRPEALIMPFISEF, VRPERCREDUCAOEF, CDCBENEF, VRALIQICMSDES
        )
      SELECT :CDFILIALDES, CDPRODUTO, VRPEALIMPFIS, CDIMPOSTO, IDTPIMPOSFIS, 
             IDINCIDEPISCOF, VRALIQIBPT, VRALIQIBPTES, CDCSTICMS, CDCSTPISCOF,
             CDCFOPPFIS, VRALIQPIS, VRALIQCOFINS, CDREGRAIT, VRPERCREDUCAO, IDMODALBASECALC, 
             CDREGRAITPC, CDCEST, NRORG, VRALIQFCP, VRPEALIMPFISEF, VRPERCREDUCAOEF, CDCBENEF, VRALIQICMSDES
        FROM ALIQIMPFIS
       WHERE (CDFILIAL = :CDFILIALORI)
         AND NRORG = :NRORG
    ";
      
    const DELETE_DESTINY_LIST_PROD = "
      DELETE
        FROM ALIQIMPFIS
       WHERE (INSTR(:CDFILIALDES, CDFILIAL) <> 0)
         AND (INSTR(:CDPRODUTO, CDPRODUTO) <> 0)
         AND NRORG = :NRORG
    ";
      
    const INSERT_DESTINY_LIST_PROD = "
      INSERT INTO ALIQIMPFIS
        (
          CDFILIAL, CDPRODUTO, VRPEALIMPFIS, CDIMPOSTO, IDTPIMPOSFIS,
          IDINCIDEPISCOF, VRALIQIBPT, VRALIQIBPTES, CDCSTICMS, CDCSTPISCOF, 
          CDCFOPPFIS, VRALIQPIS, VRALIQCOFINS, CDREGRAIT, VRPERCREDUCAO, IDMODALBASECALC, 
          CDREGRAITPC, CDCEST, NRORG, VRALIQFCP, VRPEALIMPFISEF, VRPERCREDUCAOEF, CDCBENEF, VRALIQICMSDES
        )
      SELECT :CDFILIALDES, CDPRODUTO, VRPEALIMPFIS, CDIMPOSTO, IDTPIMPOSFIS, 
             IDINCIDEPISCOF, VRALIQIBPT, VRALIQIBPTES, CDCSTICMS, CDCSTPISCOF,
             CDCFOPPFIS, VRALIQPIS, VRALIQCOFINS, CDREGRAIT, VRPERCREDUCAO, IDMODALBASECALC, 
             CDREGRAITPC, CDCEST, NRORG, VRALIQFCP, VRPEALIMPFISEF, VRPERCREDUCAOEF, CDCBENEF, VRALIQICMSDES
        FROM ALIQIMPFIS
       WHERE (CDFILIAL = :CDFILIALORI)
         AND (INSTR(:CDPRODUTO, CDPRODUTO) <> 0)
         AND NRORG = :NRORG
    ";
}